"""
===========================================
Graphene (:mod:`graphene`)
===========================================

.. currentmodule:: graphenemodeling.graphene

GrapheneModeling's ``graphene`` is the main module of the package.
The code here replicates literature on the material graphene. Every single function must include an example which demonstrates that it replicates a resource found in the literature. 

.. toctree::
	:maxdepth: 1

	graphene.monolayer
	graphene.bilayer
	graphene._constants
	

"""